import 'package:equatable/equatable.dart';
import 'package:syncrow_app/features/devices/model/group_one_touch_model.dart';
import 'package:syncrow_app/features/devices/model/one_touch_model.dart';


class OneTouchState extends Equatable {
  const OneTouchState();

  @override
  List<Object> get props => [];
}

class InitialState extends OneTouchState {}

class LoadingInitialState extends OneTouchState {}

class UpdateState extends OneTouchState {
  final OneTouchModel oneTouchModel;
  const UpdateState({required this.oneTouchModel});

  @override
  List<Object> get props => [oneTouchModel];
}

class LoadingNewSate extends OneTouchState {
  final OneTouchModel oneTouchModel;
  const LoadingNewSate({required this.oneTouchModel});

  @override
  List<Object> get props => [OneTouchModel];
}

class UpdateGroupState extends OneTouchState {
  final List<GroupOneTouchModel> oneTouchList;
  final bool allSwitches;

  const UpdateGroupState({required this.oneTouchList, required this.allSwitches});

  @override
  List<Object> get props => [oneTouchList, allSwitches];
}

class FailedState extends OneTouchState {
  final String error;

  const FailedState({required this.error});

  @override
  List<Object> get props => [error];
}

class ChangeSlidingSegmentState extends OneTouchState {
  final int value;

  const ChangeSlidingSegmentState({required this.value});

  @override
  List<Object> get props => [value];
}

class UpdateTimerState extends OneTouchState {
  final int seconds;
  const UpdateTimerState({required this.seconds});

  @override
  List<Object> get props => [seconds];
}

class TimerRunInProgress extends OneTouchState {
  final int remainingTime;

  const TimerRunInProgress(this.remainingTime);

  @override
  List<Object> get props => [remainingTime];
}

class TimerRunComplete extends OneTouchState {}

class SaveSchedule extends OneTouchState {}

class IsToggleState extends OneTouchState {
  final bool? onOff;
  const IsToggleState({this.onOff});
}

class ChangeTimeState extends OneTouchState {}

class UpdateCreateScheduleState extends OneTouchState {
  final bool createSchedule;
  UpdateCreateScheduleState(this.createSchedule);
}
