import 'package:equatable/equatable.dart';
import 'package:syncrow_app/features/devices/model/GroupWHModel.dart';
import 'package:syncrow_app/features/devices/model/water_heater.dart';

abstract class WaterHeaterState extends Equatable {
  const WaterHeaterState();

  @override
  List<Object> get props => [];
}

class WHInitialState extends WaterHeaterState {}

class  WHLoadingState extends WaterHeaterState {}

class  WHChangeLoading extends WaterHeaterState {
  const  WHChangeLoading(
   );
}

class WHModifyingState extends WaterHeaterState {
  final WHModel whStatusModel;
  const WHModifyingState({required this.whStatusModel});

  @override
  List<Object> get props => [whStatusModel];
}

class GetWHStatusState extends WaterHeaterState {
  final WHModel whStatusModel;
  const GetWHStatusState({required this.whStatusModel});

  @override
  List<Object> get props => [whStatusModel];
}



class WHFailedState extends WaterHeaterState {
  final String errorMessage;

  const WHFailedState({required this.errorMessage});

  @override
  List<Object> get props => [errorMessage];
}


class LoadingNewSate extends WaterHeaterState {
  final WHModel whModel;
  const LoadingNewSate({required this.whModel});

  @override
  List<Object> get props => [whModel];
}
class TimerRunComplete extends WaterHeaterState {}
class UpdateTimerState extends WaterHeaterState {
  final int seconds;
  const UpdateTimerState({required this.seconds});

  @override
  List<Object> get props => [seconds];
}

class TimerRunInProgress extends WaterHeaterState {
  final int remainingTime;

  const TimerRunInProgress(this.remainingTime);

  @override
  List<Object> get props => [remainingTime];
}

class SaveSchedule extends WaterHeaterState {}
class ChangeTimeState extends WaterHeaterState {}
class UpdateCreateScheduleState extends WaterHeaterState {
  final bool createSchedule;
  UpdateCreateScheduleState(this.createSchedule);
}
class IsToggleState extends WaterHeaterState {
  final bool? onOff;
  const IsToggleState({this.onOff});
}


class UpdateState extends WaterHeaterState {
  final WHModel whModel;
  const UpdateState({required this.whModel});

  @override
  List<Object> get props => [WHModel];
}

class ChangeSwitchStatusEvent extends WaterHeaterState {
  final bool value;
  final String deviceId;
  const ChangeSwitchStatusEvent({required this.value, this.deviceId = ''});
  @override
  List<Object> get props => [value, deviceId];
}

class ChangeSlidingSegmentState extends WaterHeaterState {
  final int value;

  const ChangeSlidingSegmentState({required this.value});

  @override
  List<Object> get props => [value];
}




class UpdateGroupState extends WaterHeaterState {
  final List<GroupWHModel> twoGangList;
  final bool allSwitches;

  const UpdateGroupState({required this.twoGangList, required this.allSwitches});

  @override
  List<Object> get props => [twoGangList, allSwitches];
}
